/******************************************************************************
	Copyright (C) 2004 Anthony S. Pyzdrowski, All rights reserved.

	Modify and share freely witout profit.
    Include previous credits with distributions.
******************************************************************************/

#include "ClassPad.h"
// ID code to recognize the button
#define CONVERT_ID 1

//Create the Example2Window class for the application
class Example2Window: public CPModuleWindow
{
//The global PegPrompt and CPPegString objects
	protected:
		PegPrompt* outputPrompt;
		CPPegString* ioString;

//Public methods of the Example2Window class
	public:
		Example2Window(PegRect rect, CPMainFrame* frame);	//constructor module
 		~Example2Window(){}									//destructor
		int init();											// initialization module
		void Draw();										// overload Draw
		SIGNED Message(const PegMessage &Mesg);				// event handler
		void Process();										// method to do the work
};

// constructor
Example2Window::Example2Window(PegRect rect, CPMainFrame* mf):CPModuleWindow(rect,0,0,mf)
{
	init();													// call init	
}

// initialization method
int Example2Window::init()
{
//formatting for input/output strings
	// no boarder, left justify, transparent, changable
	const WORD wStyle = FF_NONE|TJ_LEFT|AF_TRANSPARENT| TT_COPY;
	// set left margin to 10
	const SIGNED margin = 10;
	// calculate the maximum width that is available.  Get the width from the frame and subtract the margins
	const SIGNED width=mClient.Width()-2*margin;
	// create an output prompt positioned at 10,10, with a maximum width, initialized to "Example 2"
	outputPrompt = new PegPrompt(margin,10,width,"Example 2",0,wStyle);
	// create an input string positioned at 10, 20 with a maximum width, initialized to ""
	ioString = new CPPegString(margin, 20, width, "");
	// get a rectangle set to the size of the remaining main frame (after ioString)
	PegRect rr = GetMainFrame()->TopAppRectangle();
 	rr.wTop += 10;											//move down 10
	rr.wBottom = rr.wTop+15;								//set bottom 15 after top
 	rr.wLeft = (rr.wRight-rr.wLeft)/2-25;					//set left 25 short of center
	rr.wRight = rr.wLeft+50;								//set right 50 from left
	// create a text button positioned 10 pixels after ioString and centered with a width of 50 and a height of 15
	PegTextButton* b1 = new PegTextButton(rr, "Move It", CONVERT_ID, AF_ENABLED|TJ_CENTER);
	AddR(b1);												//add the button to the frame
	AddR(outputPrompt);										// add the output prompt to the frame
	AddR(ioString);											// add the input string to the frame
	SetDefaultFocus(ioString);								// set the focus to the ioString
	return 0;
}

void Example2Window::Draw()
{
		BeginDraw();										// begin of draw
		Invalidate(mClient); 								// invalidate old display
		DrawFrame();										// draw the frame
		DrawChildren();										// draw the chieldren
		EndDraw();											// end of draw
}

// decode the triggering signal
SIGNED Example2Window::Message(const PegMessage &Mesg)
{
	switch(Mesg.wType)										// determine the ID code of the event
  	{
		case SIGNAL(CONVERT_ID, PSF_CLICKED):				// the Button was CLICKED
			Process();										// perform the process
			break;
		default:
			return CPModuleWindow::Message(Mesg);
 	}
 	return 0;
}

void Example2Window::Process()
{
	CPString	tempString;									// a temp string
	CPString	StatusString;								// a string for the status bar
	PegStatusBar* bar = GetStatusBar();						// make a Status Bar
	tempString = (CPString)ioString->DataGet();				// read the ioString
	if(tempString == "")									//check if nothing was entered
		StatusString = "Type something first!!";			//create a message for the Status Bar
	else
		StatusString = "Example 2";							//put "Example 2" in the string
	bar->SetTextField(1,StatusString);						//display StatusString on the Status Bar
	outputPrompt->DataSet(tempString);						// write the string to the outputPrompt
	ioString->DataSet("");									// clear the ioString
	Draw();													// refresh the display
}

void PegAppInitialize(PegPresentationManager *pPresentation)
{
	PegRect Rect;											// create a rectangle object for the MainFrame 
	// set the rectangle to the usable size of the display
		Rect.Set(MAINFRAME_LEFT, MAINFRAME_TOP, MAINFRAME_RIGHT, MAINFRAME_BOTTOM);
	CPMainFrame *mw = new CPMainFrame(Rect);				// create the MainFrame

	PegRect AppRect;										// create a rectangle for the Application Window
	AppRect = mw->FullAppRectangle();						// size it to the MainFrame
	Example2Window *swin = new Example2Window(AppRect,mw);	// create the Application Window
	mw -> SetTopWindow(swin);								// load the application window into the MainFrame
	mw -> SetMainWindow(swin);								// set a main window  for this module
	pPresentation->Add(mw);									// add the MainFrame to the Presentation Manager
}

//error message handling
extern "C" char *ExtensionGetLang(ID_MESSAGE MessageNo)
{
	return "";
}

